__author__ = "The QIIME Development Team"
__copyright__ = "Copyright 2011, The QIIME Project"
__credits__ = ["Rob Knight", "Greg Caporaso", "Jeremy Widmann", "Kyle Bittinger", "Justin Kuczynski", "William Walters", "Jesse Zaneveld", "Dan Knights",  "Jesse Stombaugh", "Micah Hamady", "Julia Goodrich", "Meg Pirrung", "Jens Reeder", "Daniel McDonald", "Catherine Lozupone"] 
__license__ = "GPL"
__version__ = "1.8.0"
__maintainer__ = "Greg Caporaso"
__email__ = "gregcaporaso@gmail.com"
__status__ = "Development"